@@ -2,7 +2,8 @@
 # -*- sh -*-
 # vim:ft=sh:ts=8:sw=4:noet
 #
-# Suspend Script - Copyright (C) 2004 Bernard Blackham <bernard@blackham.com.au>
+# Hibernate Script
+# Copyright (C) 2004-2005 Bernard Blackham <bernard@blackham.com.au>
 #
 # The hibernate-script package is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as published by
@@ -57,7 +58,7 @@ SWSUSP_D="/etc/hibernate"
 SCRIPTLET_PATH="$SWSUSP_D/scriptlets.d /usr/local/share/hibernate/scriptlets.d /usr/share/hibernate/scriptlets.d"
 CONFIG_FILE="$SWSUSP_D/hibernate.conf"
 EXE=`basename $0`
-VERSION="1.06"
+VERSION="1.12"
 
 # Add these to the $PATH just in case.
 PATH="$PATH:/sbin:/usr/sbin"
@@ -181,6 +182,9 @@ $WRAPPED_HELP
 }
 CONFIGURATION_OPTIONS_HELP=""
 
+# FindXServer: Tries to find a running X server on the system. If one is found,
+# will set DISPLAY, XAUTHORITY and the XUSER variable, and return 0.
+# Otherwise, returns 1.
 FindXServer() {
     [ -n "$FIND_X_SERVER_RESULT" ] && return $FIND_X_SERVER_RESULT
 
@@ -199,7 +203,10 @@ FindXServer() {
 
     # Find a useful XAUTHORITY and ideally a username too if we can!
     local xuser xauth xpid
-    for xpid in `pidof kwrapper ksmserver kdeinit gnome-session X XFree86 Xorg` ; do
+    for xpid in `pidof kwrapper ksmserver kdeinit gnome-session fvwm fvwm2 pwm blackbox fluxbox X XFree86 Xorg` ; do
+	# Ensure the process still exists, and we aren't hallucinating.
+	[ -d "/proc/$xpid/" ] || continue
+
 	xauth=`awk 'BEGIN{RS="\\000";FS="="}($1 == "XAUTHORITY"){print $2}' < /proc/$xpid/environ`
 	xhome=`awk 'BEGIN{RS="\\000";FS="="}($1 == "HOME"){print $2}' < /proc/$xpid/environ`
 	xuser=`/bin/ls -ld /proc/$xpid/ | awk '{print $3}'`
@@ -226,6 +233,19 @@ FindXServer() {
     return 0
 }
 
+# UsingSuspendMethod <method name>: is called when a suspend method is chosen.
+# If a suspend method has already been chosen, the hibernate script will be
+# terminated with an error.
+UsingSuspendMethod() {
+    if [ -n "$HIBERNATE_SUSPEND_METHOD" ] ; then
+	vecho 0 "$EXE: More than one suspend method has been chosen."
+	vecho 0 "Please edit your config file so only one method is used."
+	exit 1
+    fi
+    HIBERNATE_SUSPEND_METHOD=$1
+    return 0
+}
+
 ##############################################################################
 ### Helper functions                                                       ###
 ##############################################################################
@@ -311,7 +331,7 @@ PluginConfigOption() {
 # the script. It exits the script if we don't.
 EnsureHavePrerequisites() {
     local i
-    for i in awk grep sort getopt basename ; do
+    for i in awk grep sort getopt basename chvt ; do
 	if ! command -v $i > /dev/null; then
 	    vecho 0 "Could not find required program \"$i\". Aborting."
 	    exit 1
@@ -342,7 +362,7 @@ EnsureHavePrerequisites() {
 	    local D
 	    local FN
 	    CNT=1
-	    while :; do
+	    while true ; do
 		D=`date +%s`
 		FN=/tmp/tmp.hibernate.$$$D$RANDOM$RANDOM$CNT
 		[ -f $FN ] && continue
@@ -575,7 +595,7 @@ ProcessConfigOption() {
 	logverbosity)
 	    EnsureNumeric "$option" "$params" && LOG_VERBOSITY="$params"
 	    ;;
-	swsuspvt)
+	swsuspvt|hibernatevt)
 	    EnsureNumeric "$option" "$params" && SWSUSPVT="$params"
 	    ;;
 	verbosity)
@@ -583,7 +603,7 @@ ProcessConfigOption() {
 		VERBOSITY="$params"
 	    ;;
 	distribution)
-	    [ -z "$DISTRIBUTION" ] && DISTRIBUTION="$params"
+	    [ -z "$DISTRIBUTION" ] && DISTRIBUTION=`echo $params | tr '[A-Z]' '[a-z]'`
 	    ;;
 	xdisplay)
 	    DISPLAY="$params"
@@ -617,7 +637,7 @@ ReadConfigFile() {
 	echo "This script probably won't do anything."
 	return 0
     fi
-    while : ; do
+    while true ; do
 	# Doing the read this way allows means we don't require a new-line
 	# at the end of the file.
 	read option params
@@ -639,7 +659,7 @@ AddInbuiltHelp() {
     AddOptionHelp "-F<file>, --config-file=<file>" "Use the given configuration file instead of the default ($CONFIG_FILE)"
     AddOptionHelp "--dry-run" "Don't actually do anything."
 
-    AddConfigHelp "SwsuspVT N" "If specified, output from the suspend script is redirected to the given VT instead of stdout."
+    AddConfigHelp "HibernateVT N" "If specified, output from the suspend script is redirected to the given VT instead of stdout."
     AddConfigHelp "Verbosity N" "Determines how verbose the output from the suspend script should be:
    0: silent except for errors
    1: print steps
@@ -735,7 +755,6 @@ LOGPIPE="cat"
 ERROR_TEXT=""
 
 EnsureHavePrerequisites
-EnsureHaveRoot
 
 CheckImplicitAlternateConfig $0
 
@@ -751,6 +770,7 @@ if [ -n "$HELP_ONLY" ] ; then
 fi
 DISABLE_HELP=1
 
+EnsureHaveRoot
 LoadScriptlets
 ReadConfigFile "${CONFIG_FILE}"
 ParseOptions "$@"
@@ -795,4 +815,4 @@ echo "Resumed at "`date` | $LOGPIPE > /dev/null
 
 exit $EXIT_CODE
 
-# $Id: hibernate.sh 881 2005-04-04 12:31:19Z bernard $
+# $Id: hibernate.sh 975 2005-10-02 05:54:27Z bernard $
